Skip to contents

The DataSurvival class handles the processing of the survival data for fitting a JointModel.

Usage

DataSurvival(data, formula)

Arguments

data

(data.frame) the observed time-to-event data.

formula

(formula) of the form Surv(time, event) ~ cov1 + cov2 + .... See survival::Surv() for more details, though note that this package only supports right censoring.

Value

A DataSurvival object.

Slots

data

(data.frame)
See Arguments for details.

formula

(formula)
See Arguments for details.

Examples

DataSurvival(os_data, Surv(os_time, os_event) ~ age + sex)
#> 
#>    Survival-Data Object:
#>       # of Rows     = 203
#>       # of Columns  = 12
#>       # of Events   = 108
#>       Formula       = Surv(os_time, os_event) ~ age + sex 
#>