LinkComponent
Arguments
- stan
(
StanModule) Stan code. See Details.- prior
(
Prior) The prior for the scaling coeficient.- key
(
character) Link identifier. See Details.- ...
additional arguments for
StanModel().
Details
This object provides key information needed to construct a link contribution in the survival model based on the parameters of the longitudinal model.
Each link component defines a stan function of the longitudinal model parameters which is multiplied by a model coefficient and added to the survival models hazard function.
For full details about the specification of a LinkComponent please see
vignette("extending-jmpost", package = "jmpost").
Slots
stan(
StanModule)
See Arguments.name(
character)
See Arguments.parameters(
ParameterList)
The parameter specification.
See also
Other LinkComponent:
as.StanModule.LinkComponent(),
as.list.LinkComponent(),
getParameters(),
initialValues()
Examples
LinkComponent(
stan = StanModule(),
prior = prior_normal(0, 1),
key = "custom_link"
)
#>
#> LinkComponent with parameter:
#> custom_link ~ normal(mu = 0, sigma = 1)
#>