Skip to contents

Stores the name, the prior distribution and the size of a parameter. If size is a string then this indicates the name of the variable within the stan data object that specifies the size of this parameter.

Usage

Parameter(prior, name, size = 1)

Arguments

prior

(Prior) for the parameter.

name

(string) of the parameter.

size

(numeric or string) dimension of the parameter.

Value

A Parameter object.

Slots

name

(string)
of the parameter.

prior

(Prior)
for the parameter.

size

(numeric or string)
dimension of the parameter.

Examples

Parameter(prior = prior_normal(0, 1), name = "beta")
#> 
#> Parameter Object:
#>    beta ~ normal(mu = 0, sigma = 1)
#>