Skip to contents

This class extends the general list type for containing Parameter specifications. When converted to a StanModule, the list supplies the Stan declarations and prior statements for those parameters.

Usage

ParameterList(...)

Arguments

...

(Parameter) which parameter specifications to include.

Value

A ParameterList object.

Slots

parameters

(list)
a list of Parameter objects

Examples

ParameterList(
  Parameter(prior_normal(0, 1), "intercept"),
  Parameter(prior_normal(0, 2), "slope")
)
#> 
#> ParameterList Object:
#>     intercept ~ normal(mu = 0, sigma = 1)
#>     slope ~ normal(mu = 0, sigma = 2)
#>