An object that promises to resolve to a LinkComponent object.
Inheriting from Promise and LinkComponent.
Details
The fun slot should be a function of signature function(prior, model) and should return
a LinkComponent object. An error will be thrown if the returned LinkComponent object
does not have the same key slot value as the original PromiseLinkComponent.
Examples
promise <- PromiseLinkComponent(linkDSLD, prior_normal(0, 2), "link_dsld")
resolvePromise(promise, LongitudinalGSF())
#>
#> LinkComponent with parameter:
#> link_dsld ~ normal(mu = 0, sigma = 2)
#>