Converts a StanModule object into a valid Stan program file where each
line of the returned character vector represents a line of the program
Usage
# S3 method for class 'StanModule'
as.character(x, ...)See also
Other StanModule:
StanModule-class,
as.list.StanModule(),
as_print_string.StanModule()