Returns a named list where each element of the list corresponds
to a Stan modelling block e.g. data, model, etc.
Usage
# S3 method for class 'StanModel'
as.list(x, ...)See also
Other StanModel:
StanModel-class
Returns a named list where each element of the list corresponds
to a Stan modelling block e.g. data, model, etc.
# S3 method for class 'StanModel'
as.list(x, ...)Other StanModel:
StanModel-class