Skip to contents

Converts a Prior object to a list of parameter data values for a Stan model.

Usage

# S3 method for class 'Prior'
as_stan_list(object, name, ...)

Arguments

object

(Prior) a prior Distribution

name

(character) the name of the parameter the prior distribution is for

...

Not Used.