Skip to contents

Extract a list that maps the variable names in a user-defined data.frame to standardised values.

Usage

extractVariableNames(object)

Arguments

object

the data object.

Value

A named list mapping source variables to standard names.