Returns the number of link components within the Link object
Usage
# S3 method for class 'Link'
length(x)See also
Other Link:
Link-class,
as.StanModule.Link(),
as.list.Link()
Returns the number of link components within the Link object
# S3 method for class 'Link'
length(x)Other Link:
Link-class,
as.StanModule.Link(),
as.list.Link()