Skip to contents

This function is used to specify only the initial values for a parameter. This is primarily used for hierarchical parameters whose distributions are fixed within the model and cannot be altered by the user.

Usage

prior_init_only(dist)

Arguments

dist

(Prior) a prior Distribution

Value

A Prior object.

Examples

prior_init_only(prior_normal(0, 1))
#> 
#> Prior Object:
#>    <None>
#>