Resolves a PromiseLinkComponent object to a LinkComponent object.
An error will be thrown if the returned LinkComponent object
does not have the same key slot value as the original PromiseLinkComponent.
Usage
# S3 method for class 'PromiseLinkComponent'
resolvePromise(object, model, ...)