These functions are used to enable the use of the corresponding link function between
the survival and longitudinal models in a joint model. Note that the exact implementation
of the link function is model specific, see
vignette("Statistical Specifications", package = "jmpost") for more details.
Usage
linkNone()
linkTTG(prior, model = PromiseLongitudinalModel(), ...)
linkDSLD(prior, model = PromiseLongitudinalModel(), ...)
linkIdentity(prior, model = PromiseLongitudinalModel(), ...)
linkGrowth(prior, model = PromiseLongitudinalModel(), ...)
linkShrinkage(prior, model = PromiseLongitudinalModel(), ...)Arguments
- prior
(
Prior) APriorobject.- model
(
LongitudinalModel) ALongitudinalModelobject.- ...
Not used.
Functions
linkNone(): No link (fit the survival and longitudinal models independently)linkTTG(): Time to growth linklinkDSLD(): Derivative of the SLD over time linklinkIdentity(): Current SLD value linklinkGrowth(): Growth Parameter linklinkShrinkage(): Shrinkage Parameter link
Examples
linkNone()
#>
#> No Link
linkDSLD()
#>
#> LinkComponent with parameter:
#> link_dsld ~ normal(mu = 0, sigma = 2)
#>
linkTTG(prior_normal(0, 1), model = LongitudinalGSF())
#>
#> LinkComponent with parameter:
#> link_ttg ~ normal(mu = 0, sigma = 1)
#>