This class extends the general LongitudinalModel class for using the
Generalized Stein-Fojo (GSF) model for the longitudinal outcome.
Usage
LongitudinalGSF(
mu_bsld = prior_normal(log(60), 1),
mu_ks = prior_normal(log(0.5), 1),
mu_kg = prior_normal(log(0.3), 1),
mu_phi = prior_normal(qlogis(0.5), 1),
omega_bsld = prior_lognormal(log(0.2), 1),
omega_ks = prior_lognormal(log(0.2), 1),
omega_kg = prior_lognormal(log(0.2), 1),
omega_phi = prior_lognormal(log(0.2), 1),
sigma = prior_lognormal(log(0.1), 1),
scaled_variance = FALSE,
centred = FALSE
)Arguments
- mu_bsld
(
Prior) for the mean baseline valuemu_bsld.- mu_ks
(
Prior) for the mean shrinkage ratemu_ks.- mu_kg
(
Prior) for the mean growth ratemu_kg.- mu_phi
(
Prior) for the mean proportion of cells affected by the treatmentmu_phi.- omega_bsld
(
Prior) for the baseline value standard deviationomega_bsld.- omega_ks
(
Prior) for the shrinkage rate standard deviationomega_ks.- omega_kg
(
Prior) for the growth rate standard deviationomega_kg.- omega_phi
(
Prior) for the standard deviation of the proportion of cells affected by the treatmentomega_phi.- sigma
(
Prior) for the variance of the longitudinal valuessigma.- scaled_variance
(
logical) whether the variance should be scaled by the expected value, corresponding to a multiplicative model. As a default, the variance is not scaled by the expected value, corresponding to an additive model. (See the "Statistical Specifications" vignette for more details.)- centred
(
logical) whether to use the centred parameterization.
Examples
LongitudinalGSF()
#>
#> Generalized Stein-Fojo Longitudinal Model (additive error) with parameters:
#> lm_gsf_mu_bsld ~ normal(mu = 4.09434, sigma = 1)
#> lm_gsf_mu_ks ~ normal(mu = -0.69315, sigma = 1)
#> lm_gsf_mu_kg ~ normal(mu = -1.20397, sigma = 1)
#> lm_gsf_mu_phi ~ normal(mu = 0, sigma = 1)
#> lm_gsf_omega_bsld ~ lognormal(mu = -1.60944, sigma = 1)
#> lm_gsf_omega_ks ~ lognormal(mu = -1.60944, sigma = 1)
#> lm_gsf_omega_kg ~ lognormal(mu = -1.60944, sigma = 1)
#> lm_gsf_omega_phi ~ lognormal(mu = -1.60944, sigma = 1)
#> lm_gsf_sigma ~ lognormal(mu = -2.30259, sigma = 1)
#> lm_gsf_eta_tilde_bsld ~ std_normal()
#> lm_gsf_eta_tilde_ks ~ std_normal()
#> lm_gsf_eta_tilde_kg ~ std_normal()
#> lm_gsf_eta_tilde_phi ~ std_normal()
#>