This function is used to specify only the initial values for a parameter.
This is primarily used for hierarchical parameters whose distributions
are fixed within the model and cannot be altered by the user.
Arguments
- dist
(Prior) a prior Distribution
See also
Other Prior:
prior_beta(),
prior_cauchy(),
prior_const(),
prior_const_vector(),
prior_gamma(),
prior_horseshoe(),
prior_invgamma(),
prior_logistic(),
prior_loglogistic(),
prior_lognormal(),
prior_normal(),
prior_normal_vector(),
prior_std_normal(),
prior_student_t(),
prior_uniform()
Examples
prior_init_only(prior_normal(0, 1))
#>
#> Prior Object:
#> <None>
#>