This function is used to specify only the initial values for a parameter. This is primarily used for hierarchical parameters whose distributions are fixed within the model and cannot be altered by the user.
This function is used to specify only the initial values for a parameter. This is primarily used for hierarchical parameters whose distributions are fixed within the model and cannot be altered by the user.