Applies constraints to a prior distribution to ensure any sampled numbers from the distribution fall within the constraints
Usage
set_limits(object, lower = -Inf, upper = Inf)
# S3 method for class 'Prior'
set_limits(object, lower = -Inf, upper = Inf)Examples
set_limits(prior_normal(0, 1), lower = 0)
#>
#> Prior Object:
#> normal(mu = 0, sigma = 1) T[0, ]
#>